@@ -161,7 +161,11 @@ static void mixer_popup_hide    (MixerData *data, gboolean revert);
 static void mixer_start_gmix_cb (BonoboUIComponent *uic,
 				 MixerData         *data,
 				 const gchar       *verbname);
-
+static void mixer_ui_component_event (BonoboUIComponent *comp,
+			  const gchar                  *path,
+			  Bonobo_UIComponent_EventType  type,
+			  const gchar                  *state_string,
+			  MixerData                    *data);
 void add_atk_namedesc (GtkWidget *widget, const gchar *name, const gchar *desc);
 
 static gint mixerfd = -1;
@@ -377,7 +381,7 @@ mixer_timeout_cb (MixerData *data)
 	BonoboUIComponent *component;
 	gint               vol;
 	gboolean state;
-
+	
 	if (!device_present) {
 		data->mute = TRUE;
 		mixer_update_image (data);
@@ -472,6 +476,7 @@ mixer_timeout_cb (MixerData *data)
 		mixer_update_slider (data);
 	}
 	
+	
 	return TRUE;
 }
 
@@ -515,11 +520,10 @@ mixer_update_image (MixerData *data)
 {
 	gint vol, size;
 	GdkPixbuf *pixbuf, *copy, *scaled = NULL;
-
 	vol = data->vol;
 
 	size = panel_applet_get_size (PANEL_APPLET (data->applet));
-
+	
 	if (vol <= 0)
 		pixbuf = gdk_pixbuf_copy (data->zero);
 	else if (vol <= VOLUME_MAX / 3)
@@ -547,13 +551,15 @@ mixer_update_image (MixerData *data)
 		g_object_unref (mute);
 	}
 
-
+	size = MAX (11, size);
 	scaled = gdk_pixbuf_scale_simple (pixbuf, size, size, GDK_INTERP_BILINEAR);
 	gtk_image_set_from_pixbuf (GTK_IMAGE (data->image), scaled);
-	g_object_unref (scaled);
-	gtk_widget_set_size_request (GTK_WIDGET (data->frame), 
-					     MAX (11, size), MAX (11, size));
+	g_object_unref (scaled);	
 	g_object_unref (pixbuf);
+	
+	panel_applet_gconf_set_int (PANEL_APPLET (data->applet), "vol", data->vol);
+	panel_applet_gconf_set_bool (PANEL_APPLET (data->applet), "mute", data->mute);
+			
 }
 
 static gboolean
@@ -564,7 +570,7 @@ scale_key_press_event_cb (GtkWidget *widget, GdkEventKey *event, MixerData *data
 		/* Revert. */
 		mixer_popup_hide (data, TRUE);
 		return TRUE;
-
+	
 	case GDK_KP_Enter:
 	case GDK_ISO_Enter:
 	case GDK_3270_Enter:
@@ -598,7 +604,7 @@ show_error_dialog (MixerData *data)
 	}
 	data->error_dialog = gtk_message_dialog_new (NULL,
 					 GTK_DIALOG_DESTROY_WITH_PARENT,
-					 GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
+					 GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
 					 ("Couldn't open mixer device %s\n"),
 					 data->device, NULL);
 
@@ -652,7 +658,22 @@ applet_key_press_event_cb (GtkWidget *widget, GdkEventKey *event, MixerData *dat
 		/* Revert. */
 		mixer_popup_hide (data, TRUE);
 		return TRUE;
-
+	case GDK_m:
+		if (event->state == GDK_CONTROL_MASK) {
+			Bonobo_UIComponent_EventType  type;
+			if (data->mute)
+				mixer_ui_component_event (NULL, "Mute", type, "0", data);
+			else
+				mixer_ui_component_event (NULL, "Mute", type, "1", data);
+			return TRUE;
+		}
+		break;
+	case GDK_o:
+		if (event->state == GDK_CONTROL_MASK) {
+			mixer_start_gmix_cb (NULL, data, NULL);
+			return TRUE;
+		}
+		break;
 	case GDK_KP_Enter:
 	case GDK_ISO_Enter:
 	case GDK_3270_Enter:
@@ -711,6 +732,9 @@ mixer_popup_show (MixerData *data)
 	GtkRequisition  req;
 	GtkWidget      *frame;
 	GtkWidget      *inner_frame;
+	GtkWidget      *pluslabel, *minuslabel;
+	GtkWidget 	     *event;
+	GtkWidget 	     *box;
 	gint            x, y;
 	gint            width, height;
 	GdkGrabStatus   pointer, keyboard;
@@ -731,10 +755,18 @@ mixer_popup_show (MixerData *data)
 	gtk_frame_set_shadow_type (GTK_FRAME (inner_frame), GTK_SHADOW_NONE);
 	gtk_widget_show (inner_frame);
 	
+	event = gtk_event_box_new ();
+	/* This signal is to not let button press close the popup when the press is
+	** in the scale */
+	g_signal_connect_after (event, "button_press_event",
+				  G_CALLBACK (scale_button_event), data);
+	
 	if (IS_PANEL_HORIZONTAL (data->orientation)) {
+		box = gtk_vbox_new (FALSE, 0);
 		data->scale = gtk_vscale_new (data->adj);
 		gtk_widget_set_size_request (data->scale, -1, 100);			
 	} else {
+		box = gtk_hbox_new (FALSE, 0);
 		data->scale = gtk_hscale_new (data->adj);
 		gtk_widget_set_size_request (data->scale, 100, -1);
 		gtk_range_set_inverted (GTK_RANGE (data->scale), TRUE);
@@ -745,11 +777,7 @@ mixer_popup_show (MixerData *data)
 				_("Volume Controller"),
 				_("Use Up/Down arrow keys to change volume"));
 	}
-	/* This signal is to not let button press close the popup when the press is
-	** in the scale */
-	g_signal_connect_after (data->scale, "button_press_event",
-				  G_CALLBACK (scale_button_event), data);
-	g_signal_connect (data->popup,
+	g_signal_connect_after (data->popup,
 			  "button-press-event",
 			  (GCallback) scale_button_release_event_cb,
 			  data);
@@ -768,8 +796,24 @@ mixer_popup_show (MixerData *data)
 	gtk_container_add (GTK_CONTAINER (data->popup), frame);
 	
 	gtk_container_add (GTK_CONTAINER (frame), inner_frame);
-	gtk_container_add (GTK_CONTAINER (inner_frame), data->scale);
-
+	
+	/* Translators - The + and - refer to increasing and decreasing the volume. 
+	** I don't know if there are sensible alternatives in other languages */
+	pluslabel = gtk_label_new (_("+"));	
+	minuslabel = gtk_label_new (_("-"));
+	
+	if (IS_PANEL_HORIZONTAL (data->orientation)) {
+		gtk_box_pack_start (GTK_BOX (box), pluslabel, FALSE, FALSE, 0);
+		gtk_box_pack_end (GTK_BOX (box), minuslabel, FALSE, FALSE, 0);
+	} else {
+		gtk_box_pack_start (GTK_BOX (box), minuslabel, FALSE, FALSE, 0);
+		gtk_box_pack_end (GTK_BOX (box), pluslabel, FALSE, FALSE, 0);
+	}
+	gtk_box_pack_start (GTK_BOX (box), data->scale, TRUE, TRUE, 0);
+	
+	gtk_container_add (GTK_CONTAINER (event), box);
+	gtk_container_add (GTK_CONTAINER (inner_frame), event);
+	
 	gtk_widget_show_all (inner_frame);
 	
 	/*
@@ -954,8 +998,8 @@ mixer_start_gmix_cb (BonoboUIComponent *uic,
 		dialog = gtk_message_dialog_new (NULL,
 						 GTK_DIALOG_DESTROY_WITH_PARENT,
 						 GTK_MESSAGE_ERROR,
-						 GTK_BUTTONS_CLOSE,
-						 _("There was an error executing '%s' : %s"),
+						 GTK_BUTTONS_OK,
+						 _("There was an error executing '%s': %s"),
 						 run_mixer_cmd,
 						 error->message);
 
@@ -1095,7 +1139,7 @@ show_help_cb (GtkWindow *dialog)
 				NULL,
 				GTK_DIALOG_DESTROY_WITH_PARENT,
 				GTK_MESSAGE_ERROR,
-				GTK_BUTTONS_CLOSE,
+				GTK_BUTTONS_OK,
 				_("There was an error displaying help: %s"),
 				error->message);
 
@@ -1151,17 +1195,19 @@ mixer_pref_cb (BonoboUIComponent *uic,
                                                    GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
                                                    GTK_STOCK_HELP, GTK_RESPONSE_HELP,
                                                    NULL);
+	gnome_window_icon_set_from_file (GTK_WINDOW (dialog), GNOME_ICONDIR"/mixer/gnome-mixer-applet.png");	
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CLOSE);
 	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 	gtk_window_set_screen (GTK_WINDOW (dialog),
                            gtk_widget_get_screen (GTK_WIDGET (data->applet)));
+        gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
         gtk_window_set_default_size (GTK_WINDOW (dialog), 300, 300);
         data->prefdialog = dialog;
                            
 	vbox = GTK_DIALOG (dialog)->vbox;
 	
 	vbox1 = gtk_vbox_new (FALSE, 18);
-	gtk_container_set_border_width (GTK_CONTAINER (vbox1), 12);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox1), 5);
 	gtk_box_pack_start (GTK_BOX (vbox), vbox1, TRUE, TRUE, 0);
 	
 	vbox2 = gtk_vbox_new (FALSE, 6);
@@ -1240,7 +1286,7 @@ mixer_ui_component_event (BonoboUIComponent            *comp,
 			  MixerData                    *data)
 {
 	gboolean state;
-	
+
 	if (!strcmp (path, "Mute")) {
 		if (!strcmp (state_string, "1")) {
 			state = TRUE;
@@ -1296,15 +1342,71 @@ mixer_ui_component_event (BonoboUIComponent            *comp,
 }
 
 static void
-get_prefs (MixerData *data)
-{
+get_channel (MixerData *data)
+{	
+#ifdef OSS_API
 	PanelApplet *applet = PANEL_APPLET (data->applet);
 	gint num;
-#ifdef OSS_API
+	
 	num = panel_applet_gconf_get_int (applet, "channel", NULL);
 	num = CLAMP (num, 0,  SOUND_MIXER_NRDEVICES-1);	
 	data->mixerchannel = num;
 #endif
+
+}
+
+static void
+get_prefs (MixerData *data)
+{
+	PanelApplet *applet = PANEL_APPLET (data->applet);
+	BonoboUIComponent *component;
+	gboolean mute;
+	
+	data->vol = panel_applet_gconf_get_int (applet, "vol", NULL);
+	mute = panel_applet_gconf_get_bool (applet, "mute", NULL);
+	
+	if (data->vol < 0)
+		return;
+		
+	data->mute = mute;
+	if (data->mute) {
+#ifdef SUN_API
+		set_mute_status (TRUE);
+#else
+		setMixer (0, data);
+#endif
+		mixer_update_image (data);
+		
+				
+		gtk_tooltips_set_tip (data->tooltips,
+					      data->applet,
+					      _(access_name_mute),
+					      NULL); 
+		if (gail_loaded) {
+				add_atk_namedesc (data->applet,
+						  _(access_name_mute),
+						  NULL);
+		}
+	}
+	else {
+#ifdef SUN_API
+		set_mute_status (FALSE);
+#else
+		setMixer (data->vol, data);
+#endif
+		mixer_update_image (data);
+			
+		
+		gtk_tooltips_set_tip (data->tooltips,
+				      data->applet,
+				      _(access_name),
+				      NULL); 
+		if (gail_loaded) {
+			add_atk_namedesc (data->applet,
+					  _(access_name),
+					  NULL);
+		}
+	}
 }
 
 typedef struct
@@ -1397,8 +1499,9 @@ mixer_applet_create (PanelApplet *applet)
 
 	data = g_new0 (MixerData, 1);
 	data->applet = GTK_WIDGET (applet);
-	
-	get_prefs (data);
+	panel_applet_add_preferences (applet, "/schemas/apps/mixer_applet/prefs", NULL);
+	panel_applet_set_flags (applet, PANEL_APPLET_EXPAND_MINOR);
+	get_channel (data);
 
 #ifdef OSS_API
 	/* /dev/sound/mixer for devfs */
@@ -1488,7 +1591,10 @@ mixer_applet_create (PanelApplet *applet)
 			  data);
 
 	/* Get the initial volume. */
-	data->vol = readMixer (data);
+	get_prefs (data);
+	
+	if (!data->mute)
+		data->vol = readMixer (data);
 
 	/* Install timeout handler, that keeps the applet up-to-date if the
 	 * volume is changed somewhere else.
@@ -1497,8 +1603,6 @@ mixer_applet_create (PanelApplet *applet)
 					 (GSourceFunc) mixer_timeout_cb,
 					 data);
 
-	data->mute = FALSE;
-
 	g_signal_connect (applet,
 			  "destroy",
 			  (GCallback) destroy_mixer_cb,
@@ -1531,6 +1635,18 @@ mixer_applet_create (PanelApplet *applet)
 			  "ui-event",
 			  (GCallback) mixer_ui_component_event,
 			  data);
+	if (data->mute)
+		bonobo_ui_component_set_prop (component,
+						      "/commands/Mute",
+						      "state",
+						      "1",
+						      NULL);
+	else
+		bonobo_ui_component_set_prop (component,
+						      "/commands/Mute",
+						      "state",
+						      "0",
+						      NULL);
 
 	if (run_mixer_cmd == NULL)
 		bonobo_ui_component_rm (component, "/popups/popup/RunMixer", NULL);
